@@ -1,6 +1,7 @@
 from .SURE import SURE
 from .DensityFlow import DensityFlow
 from .PerturbE import PerturbE
+from .TranscriptomeDecoder import TranscriptomeDecoder
 
 from . import utils 
 from . import codebook
@@ -9,5 +10,7 @@ from . import DensityFlow
 from . import atac
 from . import flow 
 from . import perturb
+from . import PerturbE
+from . import TranscriptomeDecoder
 
-__all__ = ['SURE', 'DensityFlow', 'PerturbE', 'flow', 'perturb', 'atac', 'utils', 'codebook']
\ No newline at end of file
+__all__ = ['SURE', 'DensityFlow', 'PerturbE', 'TranscriptomeDecoder', 'flow', 'perturb', 'atac', 'utils', 'codebook']
\ No newline at end of file
