@@ -237,7 +237,6 @@ class ZeroBiasMLP(nn.Module):
         
     # pass through our sequential for the output!
     def forward(self, x):
-        print(f'type: {type(x)}; shape: {x.shape}')
         y = self.mlp(x)
         mask = torch.zeros_like(y)
         if len(y.shape)==2:
@@ -253,6 +252,37 @@ class ZeroBiasMLP(nn.Module):
         return y*mask
         
 
+
+class ZeroBiasMLP2(nn.Module):
+    def __init__(
+        self,
+        mlp_sizes,
+        activation=nn.ReLU,
+        output_activation=None,
+        post_layer_fct=lambda layer_ix, total_layers, layer: None,
+        post_act_fct=lambda layer_ix, total_layers, layer: None,
+        allow_broadcast=False,
+        use_cuda=False,
+    ):
+        # init the module object
+        super().__init__()
+        self.mlp = MLP(mlp_sizes=mlp_sizes,
+                       activation=activation,
+                       output_activation=output_activation,
+                       post_layer_fct=post_layer_fct,
+                       post_act_fct=post_act_fct,
+                       allow_broadcast=allow_broadcast,
+                       use_cuda=use_cuda,
+                       bias=True)
+        
+    # pass through our sequential for the output!
+    def forward(self, x):
+        y = self.mlp(x)
+        mask = torch.zeros_like(y)
+        x_sum = torch.sum(x, dim=1)
+        mask[x_sum>0,:] = 1
+        return y*mask
+    
 class HDMLP(nn.Module):
     def __init__(
         self,
